package com.hp.user.service.controller;

import com.baomidou.mybatisplus.extension.plugins.PaginationInterceptor;
import com.hp.user.client.entity.CompanyPageVO;
import com.hp.user.client.entity.CustomerCompanyVO;
import com.hp.user.client.service.CustomerCompanyService;
import com.hp.user.util.IdWorker;
import com.hp.user.utils.HttpResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@Api(tags = "企业/服务商API接口")
@RestController
@RequestMapping("/company")
public class CompanyController {
    @Autowired
    private CustomerCompanyService customerCompanyService;

    /**
     * 添加企业
     * @param company 企业信息
     * @return HttpResult
     */
    @ApiOperation(value = "新增企业", notes = "新增企业", httpMethod = "POST")
    @PostMapping("/addCompany")
    public HttpResult addCompany(@RequestBody CustomerCompanyVO company){
        company.setCustomerId(IdWorker.generactorId());
        boolean flag=customerCompanyService.insert(company);
        if(flag) return HttpResult.success(company.getCustomerId());
        else return HttpResult.fail();
    }

    /**
     * 更新企业信息
     * @param company 企业信息
     * @return HttpResult
     */
    @ApiOperation(value = "更新企业信息", notes = "更新企业信息", httpMethod = "POST")
    @PostMapping("/updateCompany")
    public HttpResult updateCompany(@RequestBody CustomerCompanyVO company){
        boolean flag=customerCompanyService.update(company);
        if(flag) return HttpResult.success();
        else return HttpResult.fail();
    }

    /**
     * 根据企业Id删除企业
     * @param companyId 企业Id
     * @return HttpResult
     */
    @ApiOperation(value = "删除企业", notes = "删除企业", httpMethod = "GET")
    @GetMapping("/deleteCompanyByCompanyId")
    public HttpResult deleteCompanyByCompanyId(@RequestParam String companyId){
        boolean flag=customerCompanyService.delete(Long.parseLong(companyId));
        if(flag) return HttpResult.success();
        else return HttpResult.fail();
    }

    /**
     * 根据企业Id查询某企业信息
     * @param companyId 企业Id
     * @return CustomerCompanyVO
     */
    @ApiOperation(value="根据企业Id查询某企业信息")
    @GetMapping("/queryCompanyByCompanyId")
    public CustomerCompanyVO queryCompanyByCompanyId(@RequestParam String companyId){
        return customerCompanyService.queryCompanyByCompanyId(Long.parseLong(companyId));
    }

    /**
     * 分页查询所有企业信息
     * @param current 要查询页数
     * @param size 一页的行数
     * @return CompanyPageVO
     */
    @ApiOperation(value="分页查询所有企业",notes="输入的current为要查询的页数，size为一页的行数，返回的total为总行数")
    @GetMapping("/queryAllCompanyByPage")
    public CompanyPageVO queryAllCompanyByPage(@RequestParam Long current, @RequestParam Integer size){
        return customerCompanyService.getCompanysPage(current,size);
    }

    /**
     * 分页查询符合条件的企业信息
     * @param name 企业名称
     * @param serviceProviderName 企业关联服务商名称
     * @param status 审核状态
     * @param current 要查询页数
     * @param size 一页的行数
     * @return CompanyPageVO
     */
    @ApiOperation(value="根据企业姓名、关联服务商、审核状态分页查询企业",notes="若查询服务商，则只需要填name，serviceProviderName为空，status为0")
    @GetMapping("/queryCompanysPageByNameAndServiceProviderAndStatus")
    public CompanyPageVO queryCompanysPageByNameAndServiceProviderAndStatus(String name,String serviceProviderName,@RequestParam Integer status,@RequestParam Long current,@RequestParam Integer size){
        return customerCompanyService.queryCompanyspageByNameAndServiceAndStatus(name,serviceProviderName,status,current,size);
    }

    /**
     * 查询某企业的所有用户
     * @param companyId 企业Id
     */
    @GetMapping("/queryAllUserOfCompany")
    public void queryAllUserOfCompany(String companyId){

    }

    /**
     * 关联某企业与某用户
     * @param companyId 企业Id
     * @param userId 用户Id
     */
    @GetMapping("/associateCompanyAndUser")
    public void associateCompanyAndUser(String companyId,String userId){

    }

    /**
     * 解除某企业与某用户的关联
     * @param companyId 企业Id
     * @param userId 用户Id
     */
    @GetMapping("/dissociateCompanyAndUser")
    public void dissociateCompanyAndUser(String companyId,String userId){

    }
}
